==> openfoam_2006.210414.orig.tar.xz: .gitlab/issue_templates/bug.md <==
<!--
  *** Please read this first! ***

  Before opening a new issue, make sure to search for keywords in the issues
  filtered by the "bug" label and check to see if it has already been reported

  You can see how your report will be rendered on the platform by using the
  "preview" tab above
-->

<!--
  All text between these markers are comments and will not be present in the
  report
-->

### Summary

<!-- Summarize the bug encountered concisely -->

### Steps to reproduce

<!-- How one can reproduce the issue - this is very important -->

### Example case

<!--
  If possible, please create a SMALL example and attach it to your report

  If you are using an older version of OpenFOAM this will also determine
  whether the bug has been fixed in a more recent version
-->

### What is the current *bug* behaviour?

<!-- What actually happens -->

### What is the expected *correct* behavior?

<!-- What you should see instead -->

### Relevant logs and/or images

<!--
  Paste any relevant logs - please use code blocks (```) to format console
  output, logs, and code as it's very hard to read otherwise.
-->

### Environment information

<!--
  Providing details of your set-up can help us identify any issues, e.g.
  OpenFOAM version : v1806|v1812|v1906 etc
  Operating system : ubuntu|openSUSE|centos etc
  Hardware info    : any info that may help?
  Compiler         : gcc|intel|clang etc
 -->

- OpenFOAM version :
- Operating system :
- Hardware info    :
- Compiler         :

### Possible fixes

<!--
  If you can, link to the line of code that might be responsible for the
  problem

  The "/label ~bug" text is a gitlab flag that will add the "bug" label to this
  issue
-->

/label ~bug

==> openfoam_2106.211215.orig.tar.xz: .gitlab/issue_templates/bug.md <==
<!--
  *** Please read this first! ***

  Before opening a new issue, make sure to search for keywords in the issues
  filtered by the "bug" label and check to see if it has already been reported

  You can see how your report will be rendered on the platform by using the
  "preview" tab above
-->

<!--
  All text between these markers are comments and will not be present in the
  report
-->

### Summary

<!-- Summarize the bug encountered concisely -->

### Steps to reproduce

<!-- How one can reproduce the issue - this is very important -->

### Example case

<!--
  If possible, please create a SMALL example and attach it to your report

  If you are using an older version of OpenFOAM this will also determine
  whether the bug has been fixed in a more recent version
-->

### What is the current *bug* behaviour?

<!-- What actually happens -->

### What is the expected *correct* behavior?

<!-- What you should see instead -->

### Relevant logs and/or images

<!--
  Paste any relevant logs - please use code blocks (```) to format console
  output, logs, and code as it's very hard to read otherwise.
-->

### Environment information

<!--
  Providing details of your set-up can help us identify any issues, e.g.
  OpenFOAM version : v1806|v1812|v1906|v1912|v2006|v2012|v2106 etc
  Operating system : ubuntu|openSUSE|centos etc
  Hardware info    : any info that may help?
  Compiler         : gcc|intel|clang etc
 -->

- OpenFOAM version :
- Operating system :
- Hardware info    :
- Compiler         :

### Possible fixes

<!--
  If you can, link to the line of code that might be responsible for the
  problem

  The "/label ~bug" text is a gitlab flag that will add the "bug" label to this
  issue
-->

/label ~bug
